==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PostanowienieSadu.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class PostanowienieSadu extends GenericDPSObject {
    /**
     * POSTANOWIENIE_SADU.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * POSTANOWIENIE_SADU.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * POSTANOWIENIE_SADU.RODZAJ_POSTANOWIENIA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long rodzajPostanowieniaId;

    /**
     * POSTANOWIENIE_SADU.DATA_POSTANOWIENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataPostanowienia;

    /**
     * POSTANOWIENIE_SADU.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * POSTANOWIENIE_SADU.SAD_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long sadId;

    /**
     * POSTANOWIENIE_SADU.ZAKRES_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zakresId;

    /**
     * POSTANOWIENIE_SADU.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * POSTANOWIENIE_SADU.UWAGI
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String uwagi;

    /**
     * POSTANOWIENIE_SADU.OPIEKUN_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long opiekunId;

    /**
     * POSTANOWIENIE_SADU.DATA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataDo;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POSTANOWIENIE_SADU.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * POSTANOWIENIE_SADU.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return POSTANOWIENIE_SADU.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * POSTANOWIENIE_SADU.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return POSTANOWIENIE_SADU.RODZAJ_POSTANOWIENIA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getRodzajPostanowieniaId() {
        return rodzajPostanowieniaId;
    }

    /**
     * POSTANOWIENIE_SADU.RODZAJ_POSTANOWIENIA_ID
     *
     * @param rodzajPostanowieniaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzajPostanowieniaId(Long rodzajPostanowieniaId) {
        this.rodzajPostanowieniaId = rodzajPostanowieniaId;
    }

    /**
     * @return POSTANOWIENIE_SADU.DATA_POSTANOWIENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataPostanowienia() {
        return dataPostanowienia;
    }

    /**
     * POSTANOWIENIE_SADU.DATA_POSTANOWIENIA
     *
     * @param dataPostanowienia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataPostanowienia(Date dataPostanowienia) {
        this.dataPostanowienia = dataPostanowienia;
    }

    /**
     * @return POSTANOWIENIE_SADU.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * POSTANOWIENIE_SADU.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return POSTANOWIENIE_SADU.SAD_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSadId() {
        return sadId;
    }

    /**
     * POSTANOWIENIE_SADU.SAD_ID
     *
     * @param sadId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSadId(Long sadId) {
        this.sadId = sadId;
    }

    /**
     * @return POSTANOWIENIE_SADU.ZAKRES_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZakresId() {
        return zakresId;
    }

    /**
     * POSTANOWIENIE_SADU.ZAKRES_ID
     *
     * @param zakresId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZakresId(Long zakresId) {
        this.zakresId = zakresId;
    }

    /**
     * @return POSTANOWIENIE_SADU.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * POSTANOWIENIE_SADU.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return POSTANOWIENIE_SADU.UWAGI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getUwagi() {
        return uwagi;
    }

    /**
     * POSTANOWIENIE_SADU.UWAGI
     *
     * @param uwagi
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setUwagi(String uwagi) {
        this.uwagi = uwagi == null ? null : uwagi.trim();
    }

    /**
     * @return POSTANOWIENIE_SADU.OPIEKUN_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOpiekunId() {
        return opiekunId;
    }

    /**
     * POSTANOWIENIE_SADU.OPIEKUN_ID
     *
     * @param opiekunId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpiekunId(Long opiekunId) {
        this.opiekunId = opiekunId;
    }

    /**
     * @return POSTANOWIENIE_SADU.DATA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * POSTANOWIENIE_SADU.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PostanowienieSadu other = (PostanowienieSadu) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getRodzajPostanowieniaId() == null ? other.getRodzajPostanowieniaId() == null : this.getRodzajPostanowieniaId().equals(other.getRodzajPostanowieniaId()))
            && (this.getDataPostanowienia() == null ? other.getDataPostanowienia() == null : this.getDataPostanowienia().equals(other.getDataPostanowienia()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getSadId() == null ? other.getSadId() == null : this.getSadId().equals(other.getSadId()))
            && (this.getZakresId() == null ? other.getZakresId() == null : this.getZakresId().equals(other.getZakresId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getUwagi() == null ? other.getUwagi() == null : this.getUwagi().equals(other.getUwagi()))
            && (this.getOpiekunId() == null ? other.getOpiekunId() == null : this.getOpiekunId().equals(other.getOpiekunId()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getRodzajPostanowieniaId() == null) ? 0 : getRodzajPostanowieniaId().hashCode());
        result = prime * result + ((getDataPostanowienia() == null) ? 0 : getDataPostanowienia().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getSadId() == null) ? 0 : getSadId().hashCode());
        result = prime * result + ((getZakresId() == null) ? 0 : getZakresId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getUwagi() == null) ? 0 : getUwagi().hashCode());
        result = prime * result + ((getOpiekunId() == null) ? 0 : getOpiekunId().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", rodzajPostanowieniaId=").append(rodzajPostanowieniaId);
        sb.append(", dataPostanowienia=").append(dataPostanowienia);
        sb.append(", nr=").append(nr);
        sb.append(", sadId=").append(sadId);
        sb.append(", zakresId=").append(zakresId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", uwagi=").append(uwagi);
        sb.append(", opiekunId=").append(opiekunId);
        sb.append(", dataDo=").append(dataDo);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PostanowienieSadu.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class PostanowienieSadu extends GenericDPSObject {
    /**
     * POSTANOWIENIE_SADU.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * POSTANOWIENIE_SADU.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * POSTANOWIENIE_SADU.RODZAJ_POSTANOWIENIA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long rodzajPostanowieniaId;

    /**
     * POSTANOWIENIE_SADU.DATA_POSTANOWIENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataPostanowienia;

    /**
     * POSTANOWIENIE_SADU.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * POSTANOWIENIE_SADU.SAD_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long sadId;

    /**
     * POSTANOWIENIE_SADU.ZAKRES_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zakresId;

    /**
     * POSTANOWIENIE_SADU.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * POSTANOWIENIE_SADU.UWAGI
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String uwagi;

    /**
     * POSTANOWIENIE_SADU.OPIEKUN_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long opiekunId;

    /**
     * POSTANOWIENIE_SADU.DATA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataDo;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POSTANOWIENIE_SADU.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * POSTANOWIENIE_SADU.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return POSTANOWIENIE_SADU.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * POSTANOWIENIE_SADU.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return POSTANOWIENIE_SADU.RODZAJ_POSTANOWIENIA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getRodzajPostanowieniaId() {
        return rodzajPostanowieniaId;
    }

    /**
     * POSTANOWIENIE_SADU.RODZAJ_POSTANOWIENIA_ID
     *
     * @param rodzajPostanowieniaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzajPostanowieniaId(Long rodzajPostanowieniaId) {
        this.rodzajPostanowieniaId = rodzajPostanowieniaId;
    }

    /**
     * @return POSTANOWIENIE_SADU.DATA_POSTANOWIENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataPostanowienia() {
        return dataPostanowienia;
    }

    /**
     * POSTANOWIENIE_SADU.DATA_POSTANOWIENIA
     *
     * @param dataPostanowienia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataPostanowienia(Date dataPostanowienia) {
        this.dataPostanowienia = dataPostanowienia;
    }

    /**
     * @return POSTANOWIENIE_SADU.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * POSTANOWIENIE_SADU.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return POSTANOWIENIE_SADU.SAD_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSadId() {
        return sadId;
    }

    /**
     * POSTANOWIENIE_SADU.SAD_ID
     *
     * @param sadId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSadId(Long sadId) {
        this.sadId = sadId;
    }

    /**
     * @return POSTANOWIENIE_SADU.ZAKRES_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZakresId() {
        return zakresId;
    }

    /**
     * POSTANOWIENIE_SADU.ZAKRES_ID
     *
     * @param zakresId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZakresId(Long zakresId) {
        this.zakresId = zakresId;
    }

    /**
     * @return POSTANOWIENIE_SADU.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * POSTANOWIENIE_SADU.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return POSTANOWIENIE_SADU.UWAGI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getUwagi() {
        return uwagi;
    }

    /**
     * POSTANOWIENIE_SADU.UWAGI
     *
     * @param uwagi
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setUwagi(String uwagi) {
        this.uwagi = uwagi == null ? null : uwagi.trim();
    }

    /**
     * @return POSTANOWIENIE_SADU.OPIEKUN_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOpiekunId() {
        return opiekunId;
    }

    /**
     * POSTANOWIENIE_SADU.OPIEKUN_ID
     *
     * @param opiekunId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpiekunId(Long opiekunId) {
        this.opiekunId = opiekunId;
    }

    /**
     * @return POSTANOWIENIE_SADU.DATA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * POSTANOWIENIE_SADU.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PostanowienieSadu other = (PostanowienieSadu) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getRodzajPostanowieniaId() == null ? other.getRodzajPostanowieniaId() == null : this.getRodzajPostanowieniaId().equals(other.getRodzajPostanowieniaId()))
            && (this.getDataPostanowienia() == null ? other.getDataPostanowienia() == null : this.getDataPostanowienia().equals(other.getDataPostanowienia()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getSadId() == null ? other.getSadId() == null : this.getSadId().equals(other.getSadId()))
            && (this.getZakresId() == null ? other.getZakresId() == null : this.getZakresId().equals(other.getZakresId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getUwagi() == null ? other.getUwagi() == null : this.getUwagi().equals(other.getUwagi()))
            && (this.getOpiekunId() == null ? other.getOpiekunId() == null : this.getOpiekunId().equals(other.getOpiekunId()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getRodzajPostanowieniaId() == null) ? 0 : getRodzajPostanowieniaId().hashCode());
        result = prime * result + ((getDataPostanowienia() == null) ? 0 : getDataPostanowienia().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getSadId() == null) ? 0 : getSadId().hashCode());
        result = prime * result + ((getZakresId() == null) ? 0 : getZakresId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getUwagi() == null) ? 0 : getUwagi().hashCode());
        result = prime * result + ((getOpiekunId() == null) ? 0 : getOpiekunId().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", rodzajPostanowieniaId=").append(rodzajPostanowieniaId);
        sb.append(", dataPostanowienia=").append(dataPostanowienia);
        sb.append(", nr=").append(nr);
        sb.append(", sadId=").append(sadId);
        sb.append(", zakresId=").append(zakresId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", uwagi=").append(uwagi);
        sb.append(", opiekunId=").append(opiekunId);
        sb.append(", dataDo=").append(dataDo);
        sb.append("]");
        return sb.toString();
    }
}
